MultiplicationCompositionModule
===============================

.. currentmodule:: pykeen.nn.compositions

.. autoclass:: MultiplicationCompositionModule
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MultiplicationCompositionModule.func

   .. rubric:: Methods Documentation

   .. automethod:: func
